<?php

add_action('admin_menu', 'pm_add_options_menu');

/**
* This function asks for the current released version of PostMaster.
* If the version sent is lower than the currently available version
* the response will be markup that creates an option for the user to 
* upgrade.
*/
function pm_get_current_version() {
	$request = 'http://xforward.com/postmasterAPI.php?method=doUpdateCheck&version=1.0.3';
	return file_get_contents($request);
}

function pm_add_options_menu() {
	// Add a new submenu under Options:
    add_options_page('PostMaster Options', 'PostMaster Options', 8, 'pmoptions', 'pm_options_page');
}

/**
* This function loads default values if necessary
*/
function pm_load_default_options(&$show_credit, &$image_template, 
	&$video_template, &$img_h, &$img_w, &$attachment_dir, &$rename_attachment) {
	// defaults
	$image_template_default =
	'<a href="%img_url%"><img src="%img_url%" border="0" width="%img_w%" height="%img_h%" /></a><br />';
	$video_template_default = '<OBJECT classid=\'clsid:02BF25D5-8C17-4B23-BC80-D3488ABDDC6B\' codebase=\'http://www.apple.com/qtactivex/qtplugin.cab\'><param name="src" value="%video_url%"><param name="autoplay" value="false"><param name="controller" value="true"><param name="loop" value="false">
        <EMBED src="%video_url%" autoplay="false" controller="true" loop="false" pluginspage=\'http://www.apple.com/quicktime/download/\'></EMBED></OBJECT>';

	$show_credit = ($show_credit == NULL) ? 'on' : $show_credit;
	$image_template = ($image_template == FALSE) ? $image_template_default : $image_template;
	$video_template = ($video_template == FALSE) ? $video_template_default : $video_template;
	$img_h = ($img_h == FALSE) ? 0 : $img_h;
	$img_w = ($img_w == FALSE) ? 0 : $img_w;
	$attachment_dir = ($attachment_dir == FALSE) ? get_option('upload_path') : $attachment_dir;
	$rename_attachment = ($rename_attachment == NULL) ? 'on' : $rename_attachment;
}

/**
* This function creates the options menu page, and does crud operations on 
* the options.
*/
function pm_options_page() {
	// finally got around to making the options a name-value hash
	$pm_options = array('pm_image_post_template' => get_option('pm_image_post_template'),
		'pm_video_post_template' => get_option('pm_video_post_template'),
		'pm_credit_flag' => get_option('pm_credit_flag'),
		'pm_image_width' => get_option('pm_image_width'),
		'pm_image_height' => get_option('pm_image_height'),
		'pm_attachment_dir' => get_option('pm_attachment_dir'),
		'pm_rename_attachment' => get_option('pm_rename_attachment'));

    $hidden_field_name = 'mt_submit_hidden';

    // See if the user has posted us some information
    // If they did, this hidden field will be set to 'Y'
    if( $_POST[ $hidden_field_name ] == 'Y' ) {
        // Read their posted value
		$pm_options['pm_credit_flag'] = (!isset($_POST['pm_credit_flag' ])) ? 'off' : 'on';
        $pm_options['pm_image_post_template'] = str_replace('\\', '', $_POST[ 'pm_image_post_template' ]);
		$pm_options['pm_video_post_template'] = str_replace('\\', '', $_POST[ 'pm_video_post_template' ]);
		$pm_options['pm_image_width'] = $_POST[ 'pm_image_width' ];
		$pm_options['pm_image_height'] = $_POST[ 'pm_image_height' ];
		$pm_options['pm_attachment_dir'] = $_POST[ 'pm_attachment_dir' ];
		$pm_options['pm_rename_attachment'] = (!isset($_POST['pm_rename_attachment'])) ? 'off' : 'on';

        // Put an options updated message on the screen
?>
<div class="updated"><p><strong>Options saved</strong></p></div>
<?php

    }
	// run default loader function
	pm_load_default_options($pm_options['pm_credit_flag'], $pm_options['pm_image_post_template'], 
		$pm_options['pm_video_post_template'], $pm_options['pm_image_height'], 
		$pm_options['pm_image_width'], $pm_options['pm_attachment_dir'], 
		$pm_options['pm_rename_attachment']);

	// save the options (should put all options in hash table)
	update_option( 'pm_image_post_template', $pm_options['pm_image_post_template'] );
	update_option( 'pm_video_post_template', $pm_options['pm_video_post_template'] );
	update_option( 'pm_credit_flag', $pm_options['pm_credit_flag'] );
	update_option( 'pm_image_width', $pm_options['pm_image_width'] );
	update_option( 'pm_image_height', $pm_options['pm_image_height'] );
	update_option( 'pm_attachment_dir', $pm_options['pm_attachment_dir'] );
	update_option( 'pm_rename_attachment', $pm_options['pm_rename_attachment'] );

    // Now display the options editing screen
    echo '<div class="wrap">';
    // header
    echo '<h2>PostMaster Plugin Options</h2>';
	// is there an update?
	echo pm_get_current_version();
    // options form
    ?>

<form name="form1" method="post" action="<?php echo str_replace( '%7E', '~', $_SERVER['REQUEST_URI']); ?>">

<p class="submit" style="align: left;">
<input type="submit" name="Submit" value="Update Options &raquo;" />
</p>

<input type="hidden" name="<?php echo $hidden_field_name; ?>" value="Y">
<p><h3>Attachment Upload Directory</h3>
This is where PostMaster will save attachments. This directory *must exist* and have the proper permissions, PostMaster will not
create any directories. Also note that specifying a directory outside of the WordPress root directory may cause the embedded images
not to appear in the post.
<br/><br/>
If you check the 'use date-time stamps' box, attachments will be saved with file names like this:
<i><?php echo date('m-d-Y-his').'.jpg'; ?></i>
<br/>
Otherwise the orignial attachment name will be used (file name collisions will result in the clobbering of the old file).
<br/>
<br/>
<strong>Attachment Directory:</strong><br/>
Use date-time stamps for file names?
<input type="checkbox" name="<?php echo 'pm_rename_attachment'; ?>"
<?php if($pm_options['pm_rename_attachment'] == 'on') { echo 'checked'; } ?> />
<br/>
If you use a relative path your starting directory is: <i><?php echo dirname(__FILE__); ?></i><br/>
<input type="text" size="60" name="<?php echo 'pm_attachment_dir'; ?>" value="<?php echo $pm_options['pm_attachment_dir']; ?>" />

<hr/>
<p><h3>Templates</h3>
The markup here will determine how your posts will be displayed when viewed. If you do not like the default
template, make changes here.<br/>
Image template variables<br/>
<ul>
<li>%img_url% - The URL of the image. All extracted attachments are stored in the user-defined upload directory</li>
<li>%img_h% - The height constraint for the image when being displayed in the post.</li>
<li>%img_w% - The width constraint for the image when being displayed in the post.</li>
</ul>
Video template variables<br/>
<ul>
<li>%video_url% - The URL of the video</li>
</ul>
<br />
<strong>Notes:</strong><br/>
<ul>
<li>You can restore the default templates by deleting them and saving. This will cause the defaults to be reloaded.</li>
<li>Be *very* careful when editing the video template. Linebreaks in the wrong place will wreak havoc on your page.</li>
</ul>
<br />
<strong>Post with image template:</strong><br/>
<textarea name="<?php echo 'pm_image_post_template'; ?>" rows="12" cols="100">
<?php echo $pm_options['pm_image_post_template']; ?>
</textarea>
</p>

<p><strong>Post with video template:</strong><br/>
<textarea name="<?php echo 'pm_video_post_template'; ?>" rows="12" cols="100">
<?php echo $pm_options['pm_video_post_template']; ?>
</textarea>
</p><hr />

<p><h3>Image options</h3>
If you would like to constrain the size of the image as it appears in the post, change the values here.
<br/>
Values of 0 will keep the original image's size (only has an effect if the %img_w% and %img_h% template variables are present).<br/>
<table border="0">
<tr>
<td>
Constrain image width to:</td>
<td>
<input type="text" name="<?php echo 'pm_image_width'; ?>" value="<?php echo $pm_options['pm_image_width']; ?>" size="5"/>
</td></tr>
<tr>
<td>
Constrain image height to: 
</td>
<td>
<input type="text" name="<?php echo 'pm_image_height'; ?>" value="<?php echo $pm_options['pm_image_height'] ?>" size="5"/>
</td>
</tr>
</table>
</p>
<hr/>
<p><h3>Miscellaneous</h3>
Check the box below to add a credit link to posts that have been run through the PostMaster plugin.
<blockquote>
<font face="courier">
E.g.<br/>
&raquo; This post was processed by <a href="http://xforward.com">PostMaster</a>
</font>
</blockquote>
Show credit link: <input type="checkbox" name="<?php echo 'pm_credit_flag'; ?>" 
<?php if($pm_options['pm_credit_flag'] == 'on') {  echo 'checked'; } ?> />
<br/><br/>
This is completely optional, but it would be appreciated if you left it on :D
</p>
<hr/>
<p class="submit" style="align: left;">
<input type="submit" name="Submit" value="Update Options &raquo;" />
</p>

</form>
</div>

<?php
 
}
?>
