<?php
/*
Plugin Name: PostMaster
Plugin URI: http://blog.xforward.com/?page_id=65
Description: The PostMaster plugin allows you to make posts-by-email with multimedia attachments. It processes all incomming email-posts,extracts the attachments, and embeds them into the post body. It currently supports image and mobile video (3g2) MIME types,with more to come in the future (hopefully). Please note that version 1.0.3 only supports a single attachment.
Version: 1.0.3
Author: Brett Duncavage
Author URI: http://xforward.com
*/

/*  
Copyright 2007  Brett Duncavage (email : brett@xforward.com)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

// important that this plugin is in standard install directory, i.e. wp-content/plugins/pluginname
require(dirname(__FILE__).'/../../../wp-config.php');
// add the admin options page stuff
require_once('pm_admin_menu.php');

add_filter('phone_content', 'pm_process_post');

function pm_process_post($raw_content) {
	$exploded_content = explode("\r\n", $raw_content);
	$line_counter = 0;

	// PostMaster credit sig
	$pm_credit_sig = '<p>&raquo;This post was processed by <a href="http://xforward.com">PostMaster</a></p>';

	// test for multi-part, basically if Content-Type is missing from content, then we've
	// got a vanilla post
	if(stristr($raw_content, 'Content-Type:') == FALSE) {
		// need to clean the content of tags
		return strip_tags($raw_content);
	}

	foreach($exploded_content as $line) {
		// find the different content parts
		if (stristr($line, "Content-Type: text/plain") != FALSE or stristr($line, "Content-Type: text/html") != FALSE) {
			// crude, but should work with most messages
			// advance pointer passed blank line
			$text_content_begin = stristr($raw_content, "Content-Type: text/plain");
			if($text_content_begin == FALSE) {
				$text_content_begin = stristr($raw_content, "Content-Type: text/html");
			}

			// haven't done my research to see if this is true with *all* systems
			// this screws up when multiple line breaks are present in body
			$text_content_begin = strstr($text_content_begin, '\r\n\r\n');
			if($text_content_begin == FALSE) {
				$text_content_begin = stristr($raw_content, "Content-Type: text/plain");
				if($text_content_begin == FALSE) {
					$text_content_begin = stristr($raw_content, "Content-Type: text/html");
				}
				// where to look?
				// gonna go out on a limb here and do this:
				$text_content_begin = strstr($text_content_begin, 'Content-Transfer-Encoding: 7bit');
				// grrr getting annoyed with this
				if($text_content_begin != FALSE) {
					// make sure the content dispostion isn't part of the text payload
					if(strstr($text_content_begin, 'Content-Disposition: inline') != FALSE) {
						$text_content_begin = strstr($text_content_begin, 'Content-Disposition: inline');
						$text_content_begin = substr($text_content_begin, strlen('Content_Disposition: inline'));
					} else {
						$text_content_begin = substr($text_content_begin, strlen('Content-Transfer-Encoding: 7bit'));
					}
				}
			} else {
				$text_content_begin = substr($text_content_begin, 4);
			}
			$text_content_end_pos = strpos($text_content_begin, '\r\n\r\n');
			if($text_content_end == 0) {
				$text_content_end_pos = strpos($text_content_begin, '--');
			}
			$text_content = substr($text_content_begin, 0, $text_content_end_pos);

			// let's make sure we didn't overrun the actual message body
			if(strstr($text_content, 'Content-Type:') != FALSE) {
				// whoops that \r\n wasn't where we thought it was
				// fix this later, won't allow message body with line breaks
				$text_content_end_pos = strpos($text_content_begin, "\r");
				$text_content = substr($text_content_begin, 0, $text_content_end_pos);
			}
			// clean the text content of tags
			$text_content = strip_tags($text_content);
		} else if(stristr($line, "Content-Type: image/") != FALSE || stristr($line, "Content-Type: application/octet-stream") != FALSE) {
			// grab the binary and save it.
			$bin_content_begin = stristr($raw_content, "Content-Type: image/");

			$media_type = 'image';
			if($bin_content_begin == FALSE) {
				$bin_content_begin = stristr($raw_content, 'Content-Type: application/octet-stream');
				$media_type = 'video';
			}
			$bin_content_begin = strstr($bin_content_begin, "\r\n\r\n");
			$bin_content_begin = substr($bin_content_begin, 4);
			$bin_content_end_pos = strpos($bin_content_begin, "\r\n\r\n");

			if($bin_content_end_pos == FALSE) {
				// let's try a different delimiter
				$bin_content_end_pos = strpos($bin_content_begin, "--"); // not the best thing to use :D
			}
			$bin_content = substr($bin_content_begin, 0, $bin_content_end_pos);

			// now i *assume* this is base64 encoded, this might not always work
			// someday i'll actually detect the encoding used
			$raw_bin = base64_decode($bin_content);

			// get the name of the image
			$file_name_offset = 0;
			$file_name_begin = stristr($raw_content, "Content-Type: image/");
			if($file_name_begin == FALSE) {
				$file_name_begin = stristr($raw_content, 'Content-Type: application/octet-stream');
			}
			$file_name_begin = stristr($file_name_begin, "filename=\"");
			// not all systems use '"' in filename
			if($file_name_begin == FALSE) {
				//$file_name_begin = stristr($raw_content, "Content-Type: image/");
				$file_name_begin = stristr($raw_content, "filename=");
				$file_name_end_pos = strpos($file_name_begin, "\r\n");
				$file_name_offset = 9;
			} else {
				$file_name_end_pos = strpos($file_name_begin, "\"\r\n");
				$file_name_offset = 10;
			}
			$file_name = strtolower(substr($file_name_begin, $file_name_offset, $file_name_end_pos - $file_name_offset));
			
			if(get_option('pm_rename_attachment') == 'on') {
				// genterate a new filename with timestamp
				// not using milliseconds in order to keep compatibility with PHP4
				$date_time_str = date('m-d-Y-his');
				// get the extension from the filename
				$exts = explode('.', $file_name);
				$exts = $exts[count($exts) - 1];
				$file_name = $date_time_str.'.'.$exts;

				$save_name = get_option('pm_attachment_dir').'/'.$file_name;
				// 1.0.3 make sure file doesn't already exist!
				for($fname_idx = 0; file_exists($save_name); $fname_idx++){
					$file_name = sprintf('%s_%d.%s', $date_time_str, $fname_idx, $exts); // returns a string?!
					$save_name = get_option('pm_attachment_dir').'/'.$file_name;
				}
			} else {
				// tack on the user-defined path
				$save_name = get_option('pm_attachment_dir').'/'.$file_name;
			}

			// replacing file_put_contents with fopen and fwrite, backwards compatible with PHP4
			//$result = file_put_contents($save_name, $raw_bin);
			$result = TRUE;
			if($save_name[0] != '/') {
				// relative paths not working??
				$save_name = dirname(__FILE__).'/'.$save_name;
			}
			
			$fp = fopen($save_name, 'x');
			if($fp != FALSE) {
				$result = fwrite($fp, $raw_bin);
				fclose($fp);
			}

			// cleanup the path
			$pm_attachment_dir = get_option('pm_attachment_dir');
			$base_path = ABSPATH;
			$base_path_pos = strstr($pm_attachment_dir, $base_path);
			if($base_path_pos != FALSE) {
				$attachment_dir = substr(get_option('pm_attachment_dir'), strlen($base_path));
			} else {
				// relative path stick plugin dir before it
				$plugin_dir = substr(dirname(__FILE__), strlen($base_path));
				$attachment_dir = $plugin_dir.'/'.get_option('pm_attachment_dir');
			}
			$media_url = get_option('siteurl').'/'.$attachment_dir.'/'.$file_name;
			echo 'Save name: '.$save_name.'<br/>';
			echo 'Attachment url: '.$media_url.'<br/>';
			if($media_type == 'image') {
				$post_template = get_option('pm_image_post_template');
				$img_w = get_option('pm_image_width');
				$img_h = get_option('pm_image_height');

				$img_props = getimagesize($save_name);
				// add our img tag to the text content to finish making the post
				// check for defaults (thanks Dan!)
				if($img_w == 0) {
					$img_w = $img_props[0];
				}
				
				if($img_h == 0) {
					$img_h = $img_props[1];
				}
				
				// put the values in the post
				$final_post = str_replace('%img_url%', $media_url, $post_template);
				$final_post = str_replace('%img_w%', $img_w, $final_post);
				$final_post = str_replace('%img_h%', $img_h, $final_post);
			} else if($media_type == 'video') {
				$post_template = get_option('pm_video_post_template');
				$final_post = str_replace('%video_url%', $media_url, $post_template);
			}
			$final_post = $final_post.$text_content;
			if(get_option('pm_credit_flag') == 'on') {
				$final_post = $final_post.$pm_credit_sig;
			}
		}
	}
	return $final_post;
}
?>